Package: usethis
Title: Automate Package and Project Setup
Version: 1.4.0
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@rstudio.com", role = c("aut", "cre"), 
      comment = c(ORCID = "0000-0003-4757-117X")
    ),
    person("Jennifer", "Bryan", , "jenny@rstudio.com", role = "aut",
      comment = c(ORCID = "0000-0002-6983-2759")
    ),
    person("RStudio", role = c("cph", "fnd"))
  )
Description: Automate package and project setup tasks that are otherwise
    performed manually. This includes setting up unit testing, test 
    coverage, continuous integration, Git, 'GitHub', licenses, 'Rcpp', 'RStudio' 
    projects, and more.
License: GPL-3
URL: https://github.com/r-lib/usethis
BugReports: https://github.com/r-lib/usethis/issues
Depends: R (>= 3.1)
Imports: clipr (>= 0.3.0), clisymbols, crayon, curl (>= 2.7), desc, fs
        (>= 1.2.0), gh, git2r (>= 0.23), glue, rlang, rprojroot (>=
        1.2), rstudioapi, utils, whisker
Suggests: covr, knitr, magick, rmarkdown, roxygen2, spelling (>= 1.2),
        styler (>= 1.0.2), testthat (>= 2.0.0), withr
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2018-08-14 05:17:52 UTC; jenny
Author: Hadley Wickham [aut, cre] (<https://orcid.org/0000-0003-4757-117X>),
  Jennifer Bryan [aut] (<https://orcid.org/0000-0002-6983-2759>),
  RStudio [cph, fnd]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Repository: CRAN
Date/Publication: 2018-08-14 12:10:02 UTC
Built: R 3.4.1; ; 2018-10-29 22:33:06 UTC; windows
