Package: usethis
Title: Automate Package and Project Setup
Version: 3.1.0
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@posit.co", role = "aut",
           comment = c(ORCID = "0000-0003-4757-117X")),
    person("Jennifer", "Bryan", , "jenny@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-6983-2759")),
    person("Malcolm", "Barrett", , "malcolmbarrett@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0003-0299-5825")),
    person("Andy", "Teucher", , "andy.teucher@posit.co", role = "aut",
           comment = c(ORCID = "0000-0002-7840-692X")),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Automate package and project setup tasks that are otherwise
    performed manually. This includes setting up unit testing, test
    coverage, continuous integration, Git, 'GitHub', licenses, 'Rcpp',
    'RStudio' projects, and more.
License: MIT + file LICENSE
URL: https://usethis.r-lib.org, https://github.com/r-lib/usethis
BugReports: https://github.com/r-lib/usethis/issues
Depends: R (>= 3.6)
Imports: cli (>= 3.0.1), clipr (>= 0.3.0), crayon, curl (>= 2.7), desc
        (>= 1.4.2), fs (>= 1.3.0), gert (>= 1.4.1), gh (>= 1.2.1), glue
        (>= 1.3.0), jsonlite, lifecycle (>= 1.0.0), purrr, rappdirs,
        rlang (>= 1.1.0), rprojroot (>= 1.2), rstudioapi, stats, tools,
        utils, whisker, withr (>= 2.3.0), yaml
Suggests: covr, knitr, magick, pkgload (>= 1.3.2.1), rmarkdown,
        roxygen2 (>= 7.1.2), spelling (>= 1.2), styler (>= 1.2.0),
        testthat (>= 3.1.8)
Config/Needs/website: r-lib/asciicast, tidyverse/tidytemplate, xml2
Config/testthat/edition: 3
Config/testthat/parallel: TRUE
Config/testthat/start-first: github-actions, release
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2024-11-25 22:12:19 UTC; jenny
Author: Hadley Wickham [aut] (<https://orcid.org/0000-0003-4757-117X>),
  Jennifer Bryan [aut, cre] (<https://orcid.org/0000-0002-6983-2759>),
  Malcolm Barrett [aut] (<https://orcid.org/0000-0003-0299-5825>),
  Andy Teucher [aut] (<https://orcid.org/0000-0002-7840-692X>),
  Posit Software, PBC [cph, fnd]
Maintainer: Jennifer Bryan <jenny@posit.co>
Repository: CRAN
Date/Publication: 2024-11-26 10:20:02 UTC
Built: R 4.4.2; ; 2024-12-01 04:01:07 UTC; unix
