# Generated by roxygen2: do not edit by hand

S3method(format,github_remote_config)
S3method(print,github_remote_config)
S3method(print,sitrep)
export(browse_circleci)
export(browse_cran)
export(browse_github)
export(browse_github_actions)
export(browse_github_issues)
export(browse_github_pat)
export(browse_github_pulls)
export(browse_github_token)
export(browse_package)
export(browse_project)
export(browse_travis)
export(create_download_url)
export(create_from_github)
export(create_github_token)
export(create_package)
export(create_project)
export(create_tidy_package)
export(edit_file)
export(edit_git_config)
export(edit_git_ignore)
export(edit_r_buildignore)
export(edit_r_environ)
export(edit_r_makevars)
export(edit_r_profile)
export(edit_rstudio_prefs)
export(edit_rstudio_snippets)
export(edit_template)
export(gh_token_help)
export(git_branch_default)
export(git_credentials)
export(git_protocol)
export(git_remotes)
export(git_sitrep)
export(git_vaccinate)
export(github_token)
export(issue_close_community)
export(issue_reprex_needed)
export(local_project)
export(pr_fetch)
export(pr_finish)
export(pr_forget)
export(pr_init)
export(pr_merge_main)
export(pr_pause)
export(pr_pull)
export(pr_pull_upstream)
export(pr_push)
export(pr_resume)
export(pr_sync)
export(pr_view)
export(proj_activate)
export(proj_get)
export(proj_path)
export(proj_set)
export(proj_sitrep)
export(rename_files)
export(tidy_label_colours)
export(tidy_label_descriptions)
export(tidy_labels)
export(tidy_labels_rename)
export(ui_code)
export(ui_code_block)
export(ui_done)
export(ui_field)
export(ui_info)
export(ui_line)
export(ui_nope)
export(ui_oops)
export(ui_path)
export(ui_silence)
export(ui_stop)
export(ui_todo)
export(ui_unset)
export(ui_value)
export(ui_warn)
export(ui_yeah)
export(use_addin)
export(use_agpl3_license)
export(use_agpl_license)
export(use_apache_license)
export(use_apl2_license)
export(use_appveyor)
export(use_appveyor_badge)
export(use_article)
export(use_badge)
export(use_binder_badge)
export(use_bioc_badge)
export(use_blank_slate)
export(use_build_ignore)
export(use_c)
export(use_cc0_license)
export(use_ccby_license)
export(use_circleci)
export(use_circleci_badge)
export(use_citation)
export(use_code_of_conduct)
export(use_conflicted)
export(use_course)
export(use_coverage)
export(use_covr_ignore)
export(use_cpp11)
export(use_cran_badge)
export(use_cran_comments)
export(use_data)
export(use_data_raw)
export(use_data_table)
export(use_description)
export(use_description_defaults)
export(use_dev_package)
export(use_dev_version)
export(use_devtools)
export(use_directory)
export(use_git)
export(use_git_config)
export(use_git_credentials)
export(use_git_hook)
export(use_git_ignore)
export(use_git_protocol)
export(use_git_remote)
export(use_github)
export(use_github_action)
export(use_github_action_check_full)
export(use_github_action_check_release)
export(use_github_action_check_standard)
export(use_github_action_pr_commands)
export(use_github_actions)
export(use_github_actions_badge)
export(use_github_labels)
export(use_github_links)
export(use_github_pages)
export(use_github_release)
export(use_gitlab_ci)
export(use_gpl3_license)
export(use_gpl_license)
export(use_jenkins)
export(use_latest_dependencies)
export(use_lgpl_license)
export(use_lifecycle)
export(use_lifecycle_badge)
export(use_logo)
export(use_make)
export(use_mit_license)
export(use_namespace)
export(use_news_md)
export(use_package)
export(use_package_doc)
export(use_partial_warnings)
export(use_pipe)
export(use_pkgdown)
export(use_pkgdown_github_pages)
export(use_pkgdown_travis)
export(use_proprietary_license)
export(use_r)
export(use_rcpp)
export(use_rcpp_armadillo)
export(use_rcpp_eigen)
export(use_readme_md)
export(use_readme_rmd)
export(use_release_issue)
export(use_reprex)
export(use_revdep)
export(use_rmarkdown_template)
export(use_roxygen_md)
export(use_rstudio)
export(use_spell_check)
export(use_template)
export(use_test)
export(use_testthat)
export(use_tibble)
export(use_tidy_ci)
export(use_tidy_coc)
export(use_tidy_contributing)
export(use_tidy_description)
export(use_tidy_eval)
export(use_tidy_github)
export(use_tidy_github_actions)
export(use_tidy_issue_template)
export(use_tidy_labels)
export(use_tidy_release_test_env)
export(use_tidy_style)
export(use_tidy_support)
export(use_tidy_thanks)
export(use_travis)
export(use_travis_badge)
export(use_tutorial)
export(use_usethis)
export(use_version)
export(use_vignette)
export(use_zip)
export(with_project)
export(write_over)
export(write_union)
import(fs)
import(rlang)
importFrom(glue,glue)
importFrom(glue,glue_collapse)
importFrom(glue,glue_data)
importFrom(lifecycle,deprecated)
importFrom(purrr,map)
importFrom(purrr,map_chr)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
