# Generated by roxygen2: do not edit by hand

S3method(format,sitrep)
S3method(print,sitrep)
export(browse_cran)
export(browse_github)
export(browse_github_issues)
export(browse_github_pat)
export(browse_github_pulls)
export(browse_travis)
export(create_from_github)
export(create_package)
export(create_project)
export(edit_file)
export(edit_git_config)
export(edit_git_ignore)
export(edit_r_environ)
export(edit_r_makevars)
export(edit_r_profile)
export(edit_rstudio_snippets)
export(proj_get)
export(proj_path)
export(proj_set)
export(proj_sitrep)
export(tidy_labels)
export(use_apl2_license)
export(use_appveyor)
export(use_badge)
export(use_binder_badge)
export(use_bioc_badge)
export(use_blank_slate)
export(use_build_ignore)
export(use_cc0_license)
export(use_code_of_conduct)
export(use_course)
export(use_coverage)
export(use_cran_badge)
export(use_cran_comments)
export(use_data)
export(use_data_raw)
export(use_depsy_badge)
export(use_description)
export(use_description_defaults)
export(use_dev_package)
export(use_dev_version)
export(use_directory)
export(use_git)
export(use_git_config)
export(use_git_hook)
export(use_git_ignore)
export(use_github)
export(use_github_labels)
export(use_github_links)
export(use_gpl3_license)
export(use_lifecycle_badge)
export(use_logo)
export(use_mit_license)
export(use_namespace)
export(use_news_md)
export(use_package)
export(use_package_doc)
export(use_pipe)
export(use_pkgdown)
export(use_r)
export(use_rcpp)
export(use_readme_md)
export(use_readme_rmd)
export(use_revdep)
export(use_rmarkdown_template)
export(use_roxygen_md)
export(use_rstudio)
export(use_spell_check)
export(use_template)
export(use_test)
export(use_testthat)
export(use_tibble)
export(use_tidy_ci)
export(use_tidy_coc)
export(use_tidy_contributing)
export(use_tidy_description)
export(use_tidy_eval)
export(use_tidy_github)
export(use_tidy_issue_template)
export(use_tidy_style)
export(use_tidy_support)
export(use_tidy_thanks)
export(use_tidy_versions)
export(use_travis)
export(use_usethis)
export(use_version)
export(use_vignette)
export(write_over)
export(write_union)
import(fs)
importFrom(glue,glue)
