## Test environments
* local OS X install, R {{{ rversion }}}
* ubuntu 14.04 (on travis-ci), R {{{ rversion }}}
* win-builder (devel and release)

## R CMD check results

0 errors | 0 warnings | 1 note

* This is a new release.
