## Test environments
* local R installation, R {{{ rversion }}}
* ubuntu 16.04 (on travis-ci), R {{{ rversion }}}
* win-builder (devel)

## R CMD check results

0 errors | 0 warnings | 1 note

* This is a new release.
